@@ -1,6 +1,6 @@
 #
 #  Copyright (C) 2005 Friedrich Leisch
-#  $Id: conversion.R 2476 2006-02-24 14:25:27Z leisch $
+#  $Id: conversion.R 4121 2008-09-22 16:59:44Z leisch $
 #
 
 setOldClass("kmeans")
@@ -8,8 +8,9 @@ setOldClass("partition")
 
 as.kcca <- function(object, ...) UseMethod("as.kcca")
 
-as.kcca.kmeans <- function(object, data, ...)
+as.kcca.kmeans <- function(object, data, save.data=FALSE, ...)
 {
+    data <- as.matrix(data)
     call <- match.call()
     call[[1]] <- as.name("as.kcca")
     fam <- kccaFamily("kmeans")
@@ -19,10 +20,14 @@ as.kcca.kmeans <- function(object, data, ...)
     z@converged <- TRUE
     z@iter <- as.integer(1)
     z@call <- call
+
+    if(save.data)
+        z@data <- ModelEnvMatrix(designMatrix=data)
+
     z
 }
 
-as.kcca.partition <- function(object, data=NULL, ...)
+as.kcca.partition <- function(object, data=NULL, save.data=FALSE, ...)
 {
     call <- match.call()
     call[[1]] <- as.name("as.kcca")
@@ -33,6 +38,9 @@ as.kcca.partition <- function(object, data=NULL, ...)
         else
             data <- object$data
     }
+    else{
+        data <- as.matrix(data)
+    }
 
     fam <- kccaFamily("kmeans")
     if("metric" %in% names(object$call)){
@@ -47,6 +55,10 @@ as.kcca.partition <- function(object, data=NULL, ...)
     z@converged <- TRUE
     z@iter <- as.integer(1)
     z@call <- call
+
+    if(save.data)
+        z@data <- ModelEnvMatrix(designMatrix=data)
+
     z
 }
 
